@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <memory>
+#include <set>
 #include <string>
 #include <vector>
 
@@ -38,6 +39,7 @@ namespace plugin {
 namespace osc {
 
 using ola::network::IPV4SocketAddress;
+using std::set;
 using std::string;
 using std::vector;
 
@@ -74,7 +76,7 @@ bool OSCPlugin::StartHook() {
     port_addresses.push_back(m_preferences->GetValue(key));
   }
 
-  // For each ouput port, extract the list of OSCTargets and store them in
+  // For each output port, extract the list of OSCTargets and store them in
   // port_targets.
   OSCDevice::PortConfigs port_configs;
   for (unsigned int i = 0; i < GetPortCount(OUTPUT_PORT_COUNT_KEY); i++) {
@@ -194,6 +196,15 @@ bool OSCPlugin::SetDefaultPreferences() {
                                            DEFAULT_ADDRESS_TEMPLATE);
   }
 
+  set<string> valid_formats;
+  valid_formats.insert(BLOB_FORMAT);
+  valid_formats.insert(FLOAT_ARRAY_FORMAT);
+  valid_formats.insert(FLOAT_INDIVIDUAL_FORMAT);
+  valid_formats.insert(INT_ARRAY_FORMAT);
+  valid_formats.insert(INT_INDIVIDUAL_FORMAT);
+
+  SetValidator<string> format_validator = SetValidator<string>(valid_formats);
+
   for (unsigned int i = 0; i < GetPortCount(OUTPUT_PORT_COUNT_KEY); i++) {
     save |= m_preferences->SetDefaultValue(
         ExpandTemplate(PORT_TARGETS_TEMPLATE, i),
@@ -202,7 +213,8 @@ bool OSCPlugin::SetDefaultPreferences() {
 
     save |= m_preferences->SetDefaultValue(
         ExpandTemplate(PORT_FORMAT_TEMPLATE, i),
-        StringValidator(true), BLOB_FORMAT);
+        format_validator,
+        BLOB_FORMAT);
   }
 
   if (save) {
